@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2018 Alberts Muktupāvels
+ * Copyright (C) 2016-2020 Alberts Muktupāvels
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -62,6 +62,8 @@ gp_applet_info_new (GpGetAppletTypeFunc  func,
 
   info->backends = NULL;
 
+  info->is_disabled_func = NULL;
+
   return info;
 }
 
@@ -84,7 +86,8 @@ gp_applet_info_set_initial_setup_dialog (GpAppletInfo             *info,
  * @info: a #GpAppletInfo
  * @help_uri: the help uri
  *
- * Sets the help uri.
+ * Sets the help uri. Must be in `help:<document>` format. Optional page
+ * identifier with options and anchor can be passed to gp_applet_show_help().
  */
 void
 gp_applet_info_set_help_uri (GpAppletInfo *info,
@@ -123,6 +126,20 @@ gp_applet_info_set_backends (GpAppletInfo *info,
   info->backends = g_strdup (backends);
 }
 
+/**
+ * gp_applet_info_set_is_disabled:
+ * @info: a #GpAppletInfo
+ * @func: the function to call to check if applet should be disabled
+ *
+ * Specifies a function to be used to check if applet should be disabled.
+ */
+void
+gp_applet_info_set_is_disabled (GpAppletInfo     *info,
+                                GpIsDisabledFunc  func)
+{
+  info->is_disabled_func = func;
+}
+
 void
 gp_applet_info_free (GpAppletInfo *info)
 {
