@@ -837,6 +837,16 @@ static const GActionEntry clock_menu_actions [] = {
         { NULL }
 };
 
+static void
+expand_locations_changed (GSettings   *settings,
+                          const gchar *key,
+                          ClockApplet *clock)
+{
+        if (clock->calendar_popup != NULL) {
+                position_calendar_popup (clock);
+        }
+}
+
 static void
 format_changed (GSettings   *settings,
                 const gchar *key,
@@ -917,34 +927,20 @@ locations_changed (GSettings   *settings,
                    const gchar *key,
                    ClockApplet *cd)
 {
-        GList *l;
-        ClockLocation *loc;
-        glong id;
-
         if (!cd->locations) {
                 clock_button_set_weather (CLOCK_BUTTON (cd->panel_button),
                                           NULL,
                                           NULL);
         }
 
-        for (l = cd->locations; l; l = l->next) {
-                loc = l->data;
-
-                id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (loc), "weather-updated"));
-                if (id == 0) {
-                        id = g_signal_connect (loc, "weather-updated",
-                                               G_CALLBACK (location_weather_updated_cb), cd);
-                        g_object_set_data (G_OBJECT (loc), "weather-updated", GINT_TO_POINTER (id));
-                        g_signal_connect (loc, "set-current",
-                                          G_CALLBACK (location_set_current_cb), cd);
-                }
-        }
-
         if (cd->map_widget)
                 clock_map_refresh (CLOCK_MAP (cd->map_widget));
 
         if (cd->clock_vbox)
                 create_cities_section (cd);
+
+        if (cd->calendar_popup)
+                position_calendar_popup (cd);
 }
 
 static void
@@ -959,6 +955,19 @@ show_week_changed (GSettings   *settings,
         }
 }
 
+static void
+show_weather_changed (GSettings   *settings,
+                      const gchar *key,
+                      ClockApplet *clock)
+{
+        GWeatherInfo  *info;
+
+        if (clock->current != NULL) {
+                info = clock_location_get_weather_info (clock->current);
+                location_weather_updated_cb (clock->current, info, clock);
+        }
+}
+
 static void
 migrate_cities_to_locations (ClockApplet *self)
 {
@@ -1029,6 +1038,38 @@ migrate_cities_to_locations (ClockApplet *self)
         g_settings_reset (self->applet_settings, "cities");
 }
 
+static ClockLocation *
+create_location (ClockApplet *self,
+                 const char  *name,
+                 const char  *metar_code,
+                 double       latitude,
+                 double       longitude,
+                 gboolean     current)
+{
+        ClockLocation *loc;
+
+        loc = clock_location_new (self->wall_clock,
+                                  self->world,
+                                  name,
+                                  metar_code,
+                                  TRUE,
+                                  latitude,
+                                  longitude,
+                                  current);
+
+        g_signal_connect (loc,
+                          "weather-updated",
+                          G_CALLBACK (location_weather_updated_cb),
+                          self);
+
+        g_signal_connect (loc,
+                          "set-current",
+                          G_CALLBACK (location_set_current_cb),
+                          self);
+
+        return loc;
+}
+
 static void
 load_cities (ClockApplet *cd)
 {
@@ -1046,11 +1087,12 @@ load_cities (ClockApplet *cd)
                                     &latitude, &longitude, &current)) {
                 ClockLocation *loc;
 
-                loc = clock_location_new (cd->wall_clock,
-                                          cd->world,
-                                          name, code,
-                                          TRUE, latitude, longitude,
-                                          current);
+                loc = create_location (cd,
+                                       name,
+                                       code,
+                                       latitude,
+                                       longitude,
+                                       current);
 
                 cd->locations = g_list_prepend (cd->locations, loc);
 
@@ -1224,14 +1266,12 @@ run_prefs_edit_save (GtkButton   *button,
                 lon = -lon;
         }
 
-        loc = clock_location_new (cd->wall_clock,
-                                  cd->world,
-                                  name,
-                                  weather_code,
-                                  TRUE,
-                                  lat,
-                                  lon,
-                                  cd->locations == NULL);
+        loc = create_location (cd,
+                               name,
+                               weather_code,
+                               lat,
+                               lon,
+                               cd->locations == NULL);
 
         cd->locations = g_list_append (cd->locations, loc);
 
@@ -1828,11 +1868,26 @@ clock_applet_constructed (GObject *object)
                           G_CALLBACK (show_week_changed),
                           self);
 
+        g_signal_connect (self->applet_settings,
+                          "changed::expand-locations",
+                          G_CALLBACK (expand_locations_changed),
+                          self);
+
         g_signal_connect (self->applet_settings,
                           "changed::locations",
                           G_CALLBACK (locations_changed),
                           self);
 
+        g_signal_connect (self->applet_settings,
+                          "changed::show-weather",
+                          G_CALLBACK (show_weather_changed),
+                          self);
+
+        g_signal_connect (self->applet_settings,
+                          "changed::show-temperature",
+                          G_CALLBACK (show_weather_changed),
+                          self);
+
         g_signal_connect (self->wall_clock,
                           "notify::clock",
                           G_CALLBACK (update_clock),
