@@ -12,8 +12,6 @@
 #include "clock-map.h"
 #include "clock-sunpos.h"
 
-G_DEFINE_TYPE (ClockMap, clock_map, GTK_TYPE_WIDGET)
-
 enum {
 	NEED_LOCATIONS,
 	LAST_SIGNAL
@@ -34,7 +32,7 @@ static const gchar *marker_files[MARKER_NB] = {
 
 static guint signals[LAST_SIGNAL];
 
-typedef struct {
+struct _ClockMapPrivate {
         time_t last_refresh;
 
         gint width;
@@ -52,7 +50,9 @@ typedef struct {
 
         /* The map with the shadow composited onto it */
         GdkPixbuf *shadow_map_pixbuf;
-} ClockMapPrivate;
+};
+
+G_DEFINE_TYPE_WITH_PRIVATE (ClockMap, clock_map, GTK_TYPE_WIDGET)
 
 static void     clock_map_finalize             (GObject *);
 static void     clock_map_get_preferred_width  (GtkWidget     *this,
@@ -70,8 +70,6 @@ static void clock_map_place_locations (ClockMap *this);
 static void clock_map_render_shadow (ClockMap *this);
 static void clock_map_display (ClockMap *this);
 
-#define PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCK_MAP_TYPE, ClockMapPrivate))
-
 static void
 rgb_to_hls (gdouble *r, gdouble *g, gdouble *b)
 {
@@ -267,8 +265,6 @@ clock_map_class_init (ClockMapClass *this_class)
         widget_class->size_allocate = clock_map_size_allocate;
 	widget_class->draw = clock_map_draw;
 
-        g_type_class_add_private (this_class, sizeof (ClockMapPrivate));
-
 	/**
 	 * ClockMap::need-locations
 	 *
@@ -293,7 +289,10 @@ static void
 clock_map_init (ClockMap *this)
 {
         int i;
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv;
+
+        this->priv = clock_map_get_instance_private (this);
+        priv = this->priv;
 
         gtk_widget_set_has_window (GTK_WIDGET (this), FALSE);
 
@@ -317,9 +316,13 @@ clock_map_init (ClockMap *this)
 static void
 clock_map_finalize (GObject *g_obj)
 {
-        ClockMapPrivate *priv = PRIVATE (g_obj);
+        ClockMap *map;
+        ClockMapPrivate *priv;
 	int i;
 
+	map = CLOCK_MAP (g_obj);
+	priv = map->priv;
+
 	if (priv->highlight_timeout_id) {
 		g_source_remove (priv->highlight_timeout_id);
 		priv->highlight_timeout_id = 0;
@@ -358,7 +361,7 @@ clock_map_finalize (GObject *g_obj)
 void
 clock_map_refresh (ClockMap *this)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv = this->priv;
 	GtkWidget *widget = GTK_WIDGET (this);
 	GtkAllocation allocation;
 
@@ -396,11 +399,15 @@ clock_map_refresh (ClockMap *this)
 static gboolean
 clock_map_draw (GtkWidget *this, cairo_t *cr)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMap *map;
+        ClockMapPrivate *priv;
         GtkStyleContext *context;
         GdkRGBA  color;
         int width, height;
 
+        map = CLOCK_MAP (this);
+        priv = map->priv;
+
         context = gtk_widget_get_style_context (this);
         gtk_style_context_get_color (context, GTK_STATE_FLAG_ACTIVE, &color);
 
@@ -447,7 +454,11 @@ clock_map_get_preferred_height (GtkWidget *this,
 static void
 clock_map_size_allocate (GtkWidget *this, GtkAllocation *allocation)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMap *map;
+        ClockMapPrivate *priv;
+
+        map = CLOCK_MAP (this);
+        priv = map->priv;
 
 	if (GTK_WIDGET_CLASS (clock_map_parent_class)->size_allocate)
 		GTK_WIDGET_CLASS (clock_map_parent_class)->size_allocate (this, allocation);
@@ -463,7 +474,7 @@ clock_map_mark (ClockMap *this,
                 gdouble   longitude,
                 gint      mark)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv = this->priv;
         GdkPixbuf *marker = priv->location_marker_pixbuf[mark];
         GdkPixbuf *partial = NULL;
 
@@ -608,7 +619,7 @@ clock_map_place_location (ClockMap *this, ClockLocation *loc, gboolean hilight)
 static void
 clock_map_place_locations (ClockMap *this)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv = this->priv;
         GList *locs;
         ClockLocation *loc;
 
@@ -735,7 +746,9 @@ clock_map_render_shadow_pixbuf (GdkPixbuf *pixbuf)
 static void
 clock_map_render_shadow (ClockMap *this)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv;
+
+        priv = this->priv;
 
         if (priv->shadow_pixbuf) {
                 g_object_unref (priv->shadow_pixbuf);
@@ -763,7 +776,9 @@ clock_map_render_shadow (ClockMap *this)
 static void
 clock_map_display (ClockMap *this)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
+        ClockMapPrivate *priv;
+
+        priv = this->priv;
 
         if (priv->width > 0 || priv->height > 0)
                 clock_map_render_shadow (this);
@@ -803,10 +818,8 @@ static void
 highlight_destroy (gpointer user_data)
 {
        BlinkData *data = user_data;
-       ClockMapPrivate *priv;
 
-       priv = PRIVATE (data->map);
-       priv->highlight_timeout_id = 0;
+       data->map->priv->highlight_timeout_id = 0;
 
        g_object_unref (data->location);
        g_free (data);
@@ -818,7 +831,7 @@ clock_map_blink_location (ClockMap *this, ClockLocation *loc)
        BlinkData *data;
        ClockMapPrivate *priv;
 
-       priv = PRIVATE (this);
+       priv = this->priv;
 
        g_return_if_fail (IS_CLOCK_MAP (this));
        g_return_if_fail (IS_CLOCK_LOCATION (loc));
@@ -842,13 +855,12 @@ clock_map_blink_location (ClockMap *this, ClockLocation *loc)
 static gboolean
 clock_map_needs_refresh (ClockMap *this)
 {
-        ClockMapPrivate *priv = PRIVATE (this);
         time_t now_t;
 
         time (&now_t);
 
 	/* refresh once per minute */
-	return (ABS (now_t - priv->last_refresh) >= 60);
+	return (ABS (now_t - this->priv->last_refresh) >= 60);
 }
 
 void
