@@ -844,15 +844,19 @@ launch (GpLauncherApplet *self,
 
       if (app_info != NULL)
         {
+          GdkDisplay *display;
+          GdkAppLaunchContext *context;
           GSpawnFlags flags;
           GError *error;
 
+          display = gdk_display_get_default ();
+          context = gdk_display_get_app_launch_context (display);
           flags = G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD;
 
           error = NULL;
           g_desktop_app_info_launch_uris_as_manager (app_info,
                                                      uris,
-                                                     NULL,
+                                                     G_APP_LAUNCH_CONTEXT (context),
                                                      flags,
                                                      child_setup,
                                                      app_info,
@@ -860,6 +864,8 @@ launch (GpLauncherApplet *self,
                                                      NULL,
                                                      &error);
 
+          g_object_unref (context);
+
           if (error != NULL)
             {
               gp_launcher_show_error_message (NULL,
